@@ -14,7 +14,7 @@ DEFAULT_NOTEBOOK_ALLOWED = {
 def pytest_configure(config):
     config.addinivalue_line(
         'markers',
-        "notebook-check: Test to check notebooks are cleaned and under allowed directories")
+        f"{PLUGIN_NAME}: Test to check notebooks are cleaned and under allowed directories")
 
 
 def pytest_addoption(parser):
@@ -61,6 +61,8 @@ class NotebookCheckItem(pytest.Item):
         super().__init__(name, parent)
         self.add_marker(PLUGIN_NAME)
 
+        self._nodeid += f"::{PLUGIN_NAME}"
+
     def runtest(self):
         error_messages = []
         dir_error = self.check_notebook_dir()
